==> nextcloud-12.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/sr.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "чувам...",
    "saved!" : "сачувано!",
    "failed!" : "неуспех!",
    "Saved" : "Сачувано",
    "There was a problem saving your changes. Click to resume editing." : "Десио се проблем приликом уписа ваших измена. Кликните за наставак уређивања.",
    "An error occurred!" : "Дошло је до грешке!",
    "Edit" : "Измени",
    "Mixed" : "Мешано",
    "Preview" : "Преглед",
    "New text file" : "Нови текстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt",
    "You can not open a folder" : "Не можете да отворите фасциклу",
    "This file is too big to be opened. Please download the file instead." : "Фајл је превелик за отварање. Преузмите га уместо отварања.",
    "Cannot read the file." : "Не могу да прочитам фајл.",
    "Invalid file path supplied." : "Дата је неисправна путања фајла.",
    "The file is locked." : "Фајл је закључан.",
    "An internal server error occurred." : "Десила се интерна грешка.",
    "You can not write to a folder" : "Не можете да уписујете у фасциклу",
    "Cannot save file as it has been modified since opening" : "Не могу да сачувам фајл јер је измењен откако је отворен",
    "Insufficient permissions" : "Недовољне дозволе",
    "File path not supplied" : "Није добијена путања фајла",
    "File mtime not supplied" : "Није добијено време измене фајла",
    "Text editor" : "Уређивач текста",
    "Text file" : "Текстуални фајл"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/sr.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "чувам...",
    "saved!" : "сачувано!",
    "failed!" : "неуспех!",
    "Saved" : "Сачувано",
    "There was a problem saving your changes. Click to resume editing." : "Десио се проблем приликом уписа ваших измена. Кликните за наставак уређивања.",
    "An error occurred!" : "Дошло је до грешке!",
    "Edit" : "Измени",
    "Mixed" : "Мешано",
    "Preview" : "Преглед",
    "New text file" : "Нови текстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt",
    "You can not open a folder" : "Не можете да отворите фасциклу",
    "This file is too big to be opened. Please download the file instead." : "Фајл је превелик за отварање. Преузмите га уместо отварања.",
    "Cannot read the file." : "Не могу да прочитам фајл.",
    "Invalid file path supplied." : "Дата је неисправна путања фајла.",
    "The file is locked." : "Фајл је закључан.",
    "An internal server error occurred." : "Десила се интерна грешка.",
    "You can not write to a folder" : "Не можете да уписујете у фасциклу",
    "Cannot save file as it has been modified since opening" : "Не могу да сачувам фајл јер је измењен откако је отворен",
    "Insufficient permissions" : "Недовољне дозволе",
    "File path not supplied" : "Није добијена путања фајла",
    "File mtime not supplied" : "Није добијено време измене фајла",
    "Share not found" : "Дељење није нађено",
    "You are not authorized to open this share" : "Нисте овлашћени да отворите ово дељење",
    "Invalid range request" : "Неисправан захтев опсега",
    "Text editor" : "Уређивач текста"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
